爆裂鼓手 (豆瓣)
Description: 爆裂鼓手电影简介和剧情介绍,爆裂鼓手影评、图片、预告片、影讯、论坛、在线购票
Keywords: 爆裂鼓手,Whiplash,爆裂鼓手影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.182豆瓣电影Top250

# 爆裂鼓手 Whiplash (2014)

导演: 达米恩·查泽雷
编剧: 达米恩·查泽雷
主演: 迈尔斯·特勒 / J·K·西蒙斯 / 保罗·雷瑟 / 梅莉莎·班诺伊 / 奥斯汀·斯托维尔 / 内特·朗 / 克里斯·马尔基 / 达蒙·冈普顿 / Suanne Spoke / 马科斯·卡锡 / Charlie Ian / 杰森·布莱尔 / 科菲·斯里博伊 / 卡维塔帕蒂尔 / C.J. Vana / 塔里克·洛维 / 卡尔文·C·温布什 / 迈克尔·D·科恩 / 艾普尔·格雷斯 / 马库斯·亨德森 / 亨利·G.桑德斯 / 温迪·李 / 米歇尔·拉夫
类型: 剧情 / 音乐
制片国家/地区: 美国
语言: 英语
上映日期: 2014-01-16(圣丹斯电影节) / 2014-10-10(美国)
片长: 107分钟
又名: 鼓动真我(港) / 进击的鼓手(台) / 鼓动人生(台) / 鞭打 / The Whiplash Drummer
IMDb: tt2582802
豆瓣评分
引用
8.7
554711人评价
5星
47.1%
4星
40.5%
3星
10.9%
2星
1.0%
1星
0.4%
好于 98% 音乐片
好于 97% 剧情片
想看 看过
评价:
推荐

## 爆裂鼓手的剧情简介 · · · · · ·

19岁少年安德鲁（迈尔斯·特勒 Miles Teller 饰）成长在单亲家庭，一心想成为顶级爵士乐鼓手。某晚他在学校练习时被魔鬼导师弗莱彻（J·K·西蒙斯 J.K. Simmons 饰）相中，进入正规乐队，同时也开始为追求完美付出代价。安德鲁越是刻苦练习，与外部世界越是隔膜。唯一理解他的是弗莱彻，但后者的暴躁与喜怒无常扭曲了这段师生关系，更让安德鲁耳濡目染，连带自身的性格亦发生变化。最后当安德鲁终于登上纽约音乐厅的舞台，他才惊恐的发现原来弗莱彻一直等着将他打入尘埃......
《爆裂鼓手》讲述一名少年在严师督教下，以非常规手段挑战自己的极限、追逐爵士乐鼓手梦的热血故事。主人公热爱打鼓，但过度的投入让他失去对音乐的初衷，进而演变为生命的负荷以及师徒间近乎疯魔的对决。电影不只有音乐人的苦痛，更让人看到传统励志背后的残酷真相。 《爆裂鼓手》获得第30届圣丹... (展开全部) 19岁少年安德鲁（迈尔斯·特勒 Miles Teller 饰）成长在单亲家庭，一心想成为顶级爵士乐鼓手。某晚他在学校练习时被魔鬼导师弗莱彻（J·K·西蒙斯 J.K. Simmons 饰）相中，进入正规乐队，同时也开始为追求完美付出代价。安德鲁越是刻苦练习，与外部世界越是隔膜。唯一理解他的是弗莱彻，但后者的暴躁与喜怒无常扭曲了这段师生关系，更让安德鲁耳濡目染，连带自身的性格亦发生变化。最后当安德鲁终于登上纽约音乐厅的舞台，他才惊恐的发现原来弗莱彻一直等着将他打入尘埃......
《爆裂鼓手》讲述一名少年在严师督教下，以非常规手段挑战自己的极限、追逐爵士乐鼓手梦的热血故事。主人公热爱打鼓，但过度的投入让他失去对音乐的初衷，进而演变为生命的负荷以及师徒间近乎疯魔的对决。电影不只有音乐人的苦痛，更让人看到传统励志背后的残酷真相。 《爆裂鼓手》获得第30届圣丹斯电影节最高荣誉评审团奖。 ©豆瓣

## 爆裂鼓手的演职员 · · · · · · ( 全部 36 )

- 达米恩·查泽雷 导演
- 迈尔斯·特勒 饰 Andrew
- J·K·西蒙斯 饰 Fletcher
- 保罗·雷瑟 饰 Jim Neimann
- 梅莉莎·班诺伊 饰 Nicole
- 奥斯汀·斯托维尔 饰 Ryan

## 爆裂鼓手的视频和图片 · · · · · · ( 预告片7 | 视频评论1 · 添加 | 图片1019 · 添加 )

## 爆裂鼓手的获奖情况 · · · · · · ( 全部 )

- 第87届奥斯卡金像奖
- 最佳影片(提名)
- 杰森·布伦 / 戴维·兰开斯特 / 海伦·埃斯特布鲁克

- 第72届金球奖
- 电影类 最佳男配角
- J·K·西蒙斯

- 第39届日本电影学院奖
- 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  海上钢琴师

  百万美元宝贝

  波西米亚狂想曲

  海盗电台

  醉乡民谣

  再次出发之纽约遇见你

  放牛班的春天

  荒岛余生

  心灵捕手

  肖申克的救赎

我要写短评

## 爆裂鼓手的短评 · · · · · · ( 全部 147435 条 )

热门 / 最新 / 好友

### 4191 有用 荞麦 看过 2015-01-21 11:16:32

清晰果断。……另外这部电影真是不错的试金石，看看短评就知道了。只从中看到痛苦，而看不到痛苦之中挟裹着快乐的人，大概从没认真追求过什么。

### 1417 有用 亵渎电影 看过 2015-01-07 01:10:36

J.k.西蒙斯应该能拿下男配！这片子的节奏感实在太棒了，爵士乐和剪辑简直融为一体了，还有西蒙斯机关枪版恶毒的台词，脏字就像鼓点一样密集且激烈，几场打鼓的重头戏在镜头上都是细碎古怪，靠剪辑重新赋予整体戏一气呵成且不断加速的节奏，可惜整部电影还是碎的，否则就真成大卫·芬奇了。★★★★

### 1431 有用 柏林苍穹下 看过 2015-01-07 01:36:31

他得到了世界，他失去了灵魂。

### 892 有用 海带岛 看过 2015-12-12 21:28:59

我身边很多朋友讨厌《爆裂鼓手》。但我很喜欢。可能因为我没觉得它在讲音乐。它太绝望了，一个注定不是天才的人，期望接近不朽哪怕多一点。正因为他追求不朽的方式如此费尽心机、如此大动干戈，简直像自毁，认真得透出滑稽，我才觉得可以和他交流。这片子当时看得我挺难过，又兴奋又难过。

### 415 有用 陀螺凡达可 看过 2014-05-24 08:33:04

音符般流动的炫目剪辑真是赏心悦目，结尾SOLO让全场观众High到爆血管，爵士酒吧似真似假的“自白”是全片戏肉。迈尔斯·特勒和J·K·西蒙斯的巅峰表演火花四溅。不过好几个段落完全照搬《社交网络》，不少情节设置为了追求戏剧化也稍嫌刻意。

> 更多短评 147435条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 爆裂鼓手的影评 · · · · · · ( 全部 2368 条 )

热门 / 最新 / 好友
黄青蕉 2015-01-23 14:31:48

## 被嫌弃的地才的一生

这是一部我永远也没办法公正的当做一部电影来评价的电影。 看这部电影的每一分钟，我的神经元都在飞速的调集着一模一样的回忆，凭着兴趣入行的新人，魔鬼特训官导师，层层重压下的精神崩溃，羞辱的眼泪，恶毒的诅咒，电影行至一半，男主为了拿到鼓棒准时参赛，出了车祸还要爬出... (展开)
10716 559 405回应 收起
小斑 2015-01-08 05:31:38

## 啪。啪啪啪……啪啪啪啪啪啪啪啪啪啪啪啪啪啪啪啪啪啪啪啪啪啪啪啪

去往生命大和谐的电梯：http://movie.douban.com/review/7328366/?start=100#comments 生命更加和谐的电梯：http://movie.douban.com/review/7328366/?start=200#comments If you don't have ability, you wind up playing in a rock band -- by Buddy Rich Buddy Rich和Cha... (展开)
6018 402 384回应 收起
Z 2014-12-21 11:42:52

## 并非你想象的励志电影

这篇影评可能有剧透

作为今年圣丹斯的获奖影片和奥斯卡热门，影片的上佳口碑主要来自于紧凑的剪辑、优质的表演和对于师徒关系非常规的刻画。诚然，影片的剪辑凌厉而准确，除结尾处有少许松懈，整部电影更像是一部动作悬疑片，节奏一再加快，冲突一再升级，影片结束，107分钟不知不觉中过去。影片对... (展开)
3343 278 257回应 收起
安德烈大叔 2015-01-08 15:54:22

## 进入终极殿堂的献祭攻略

“玉不琢不成器，不疯魔不成活”这是《爆裂鼓手》给人最为直观的第一感觉，前者带有显而易见的励志成分，而后者代表的是电影黑色的一部分，要是只是严师出高徒的音乐励志片，那该片肯定就无趣多了，幸亏电影中的师与徒都不是那种精神正常的手艺人，他们是精神偏执的野... (展开)
1352 57 108回应 收起
猫伯爵 2015-01-24 20:48:15

## 毁灭式造星法

假设这样一个问题，如果上帝给你选择两种投胎模式： 一种是过天才的一生，你将被自己才华所带来巨大的名利地位财富包围，但是你年纪轻轻就会死去。另外一种是，过一个正常普通平凡的人生，上班下班家庭子女，你会健健康康的寿终正寝。 你会如何选择？我想每个人的答案都不会... (展开)
650 16 45回应 收起
Tseraph 2015-01-09 23:06:53

## 但是，Andrew，代价是什么？

半夜看完电影，上豆瓣mark一下写了个小短评就准备睡了。打开网页面对8.8的高分和清一色的好评。我不禁有点不淡定了。在这里写一点自己的想法。 毫无疑问本片演员和乐手的发挥以及剪辑都是一流水准。就冲把Caravan的演奏过程剪的如此过瘾就绝对值得一看。 但是片子的价值观我只... (展开)
960 256 213回应 收起
沉思羊 2015-01-09 09:12:33

## 音乐不是男子100米决赛——一个偏执音乐生的自白

时隔多年的update: [How to truly listen | Evelyn Glennie] -------------------------------------------------------原文分界线------------------------------------------------------------ 一开始我还带着不屑，因为影片呈现出的爵士乐团跟我所经历的完全不一样。侮辱性... (展开)
352 57 94回应 收起
远子 2015-01-24 18:48:17

## 我这都是为你好

看完这部电影之后，我做了一个关于高考的噩梦，所以忍不住想多说几句。 我在给这部电影的短评里写道：如果我是那个老师的学生，我大概也会自杀的吧……有人在我广播下回复说：你懂个JB，没学过音乐的人都不会懂 。 我确实不懂，学音乐就一定要惨成这样？历史上的音乐大师都是在... (展开)
295 49 69回应 收起
小海 2015-02-27 16:04:42

## 你对我不屑一顾，我也一样

这世界上有许多人同时无法理解这样几件事：乔布斯为什么死得早，科比性格为什么那么扭曲，爆裂鼓手中的导师弗莱彻为什么不是反派，而是正派。 在张亮写的关于乔布斯的万字长文下，曾有人发表了这样的评价：然后就是因为他是乔布斯所以他对自己身体病情犯下的错误也被冠以“他始... (展开)
344 58 45回应 收起
恶魔奶爸Sam 2019-04-08 13:32:17

## 推崇弗莱彻和这种方法理念的傻逼们，应该先学点基础的教育学方法论

反对或者痛斥弗莱彻的人，估计有90%不太懂现代教育学方法。 推崇和赞同弗莱彻的傻逼们，肯定100%不懂现在教育学方法。 这部电影值得所有人都看看，尤其对其中的教育手段，我一定要提醒大家注意的是： 弗莱彻导师全程只有逼迫，没有干货。 逼迫是最低劣的教育手段，任何一个傻逼... (展开)
179 23 36回应 收起

> 更多影评 2368篇

添加新讨论

## 讨论区 · · · · · ·

导师的目的是在激励他还是在报复他？ | 来自聪丶初墨 | 107 回应 | 2022-11-24 10:23:43
他的节奏到底有没有问题？ | 来自药寮 | 6 回应 | 2022-11-22 13:51:14
你们不觉得和中国的应试教育很像吗？ | 来自娜吉雅 | 74 回应 | 2022-11-21 19:23:31
个人疑问，既然主角很有天赋，那么进入音乐学院的... | 来自momo | 1 回应 | 2022-11-15 21:57:48
逼一把。废了，因为你就不是这块料，成了，因为我... | 来自Stone | 6 回应 | 2022-11-14 19:14:39

> 去这部影片的讨论区（全部223条）

## 关于《爆裂鼓手》的问题 · · · · · · ( 全部136个 )

- 打算在班级上放，请问哪位看完的知不知道其中有没有不适合的镜头？ 53人回答
- 真的有那么牛逼？说实话最后的没看太懂，谁给我讲讲？ 60人回答

> 全部136个问题

## 在哪儿看这部电影 · · · · · ·

- 优酷视频 VIP免费观看
- 芒果TV VIP免费观看
- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 125部反类型片 (远山近海)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)
- 豆瓣电影【口碑榜】2022-06-13 更新 (影志)
- 2014新电影（这些，可以期待） (桃桃林林)

## 谁在看这部电影 · · · · · ·

- ChiaraC
  9分钟前 看过
- 杨坚强
  11分钟前 看过
- 雨滴NaN
  12分钟前 想看

781092人看过 / 239018人想看

订阅爆裂鼓手的评论:
feed: rss 2.0